@@ -14,21 +14,15 @@ You Should Only Skid My Projects Since I allow People Todo So!
 
 People Spend Hours Coding These Scripts Just For You!
 Not To Steal The Code But For You To Use The Service.
-Some People Like Oli (Another Lobbybot Owner https://partybot.net)
-had to put a really alarming message for the skids because he wanted
-his work to be private!
-I aspire to be like Gomashio(https://github.com/gomashio1596) or pdf(https://github.com/pdf114514)
-where i help people in terms of coding. Or any technical problems.
-Gomashio or PDF if you see this keep up the great work <3
-
-
-I Spent Alot Of Time On This Bot So if You Could Support Me By Joining I would appreciate it!
+I Spent Alot Of Time On This Bot So if You Could Support Me I would appreciate it!
     - Pirxcy
 """ 
 import fortnitepy
 import traceback
 import sanic
 import logging
+import random
+import string
 import PirxcyPinger
 import crayons
 import json
@@ -39,7 +33,7 @@ import aiohttp
 
 from fortnitepy.ext import commands
 from sanic import Sanic
-from .endpoints import web as endpoints
+
 
 def cyan(string):
   output = crayons.cyan(string)
@@ -53,10 +47,10 @@ def green(string):
   output = crayons.green(string)
   return str(output)
 
-app = Sanic(__name__)
+app = Sanic("pb4")
 loop = asyncio.get_event_loop()
 
-app.blueprint(endpoints, url_prefix="/")
+code = None
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -69,16 +63,155 @@ logger.addHandler(ch)
 def clear():
   os.system('cls || clear')
 
+def id_generator(size=6, chars=string.ascii_uppercase + string.digits):
+  return ''.join(random.choice(chars) for _ in range(size))
+
+@app.route("/")
+async def index(request):
+  return sanic.response.html(
+  """
+<html>
+   <head>
+      <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.2.1/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-iYQeCzEYFbKjA/T2uDLTpkwGzCiq6soy8tYaI1GyVh/UjpbCx/TYkiZhlZB6+fzT" crossorigin="anonymous">
+      <style>
+         body {
+         font-family:sans-serif;
+         position: absolute;
+         left: 50%;
+         top: 50%;  
+         -webkit-transform: translate(-50%, -50%);
+         transform: translate(-50%, -50%);
+         background-repeat: no-repeat;
+         background-attachment:local;
+         background-size: cover;
+         background-color: #87CEEB;
+         color: #f1f1f1;
+         }
+      </style>
+      <style type="text/css">
+        @font-face {
+            font-family: "fn";
+            src: url(https://devboogiefncf.n-dev.repl.co/Burbank.otf) format("truetype");
+        }
+        .font { 
+            font-family: "fn", Verdana, Tahoma;
+            font-size: 100px;
+        }
+        </style>
+   </head>
+   <body>
+      <center>
+            <h2 class="font">
+""" +
+f"""
+            Client Logged in as {bot.user.display_name}
+            <h2>
+              <button onclick="location.href='/dash';" class="btn btn btn-outline-light  btn-lg">
+                Dashboard
+              </button>
+            </h2>
+         </h2>
+      </center>
+   </body>
+</html>
+  """
+  )
+
+@app.route(
+  "/dash",
+  methods=[
+    "GET",
+    "POST",
+  ]
+)
+async def dashboard(request):
+  method = request.method
+  config = open_config()
+  if method == "GET":
+    user = await bot.fetch_profile(
+      user=config['owner'],
+      cache=True
+    )
+    displayName = user.display_name
+    global code
+    code = str(id_generator(size=4))
+    return sanic.response.html(
+      """
+<html>
+   <head>
+      <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.2.1/dist/css/bootstrap.min.css" rel="stylesheet" integrity="sha384-iYQeCzEYFbKjA/T2uDLTpkwGzCiq6soy8tYaI1GyVh/UjpbCx/TYkiZhlZB6+fzT" crossorigin="anonymous">
+      <style>
+         body {
+         font-family:sans-serif;
+         position:fixed;
+         left: 50%;
+         top: 50%;  
+         -webkit-transform: translate(-50%, -50%);
+         transform: translate(-50%, -50%);
+         background-repeat: no-repeat;
+         background-attachment:local;
+         background-size: cover;
+         background-color: #87CEEB;
+         color: #f1f1f1;
+         }
+      </style>
+      <style type="text/css">
+        @font-face {
+            font-family: "fn";
+            src: url(https://devboogiefncf.n-dev.repl.co/Burbank.otf) format("truetype");
+        }
+        .ptitle {
+            font-family: Arial, sans-serif;
+            font-size: 50px;
+        }
+        .font { 
+            font-family: "fn", Verdana, Tahoma;
+            font-size: 75px;
+        }
+        .fontn{ 
+         font-family: "fn", Verdana, Tahoma;
+         color: black;
+         font-size: 75px
+         }
+         .fontf{ 
+            font-family: "fn", Verdana, Tahoma;
+            color: black;
+            }
+        </style>
+   </head>
+   <body>
+   """ +
+   f"""
+      <center>
+         <h2 class = "ptitle">
+            Whisper <span class="font">{bot.user.display_name}</span> The Following Command:<br>"!verify <span class="fontn">{code}</span>"
+         </h2>
+         <h2 class>
+            Make sure your using the admin account (<span class="fontf">{displayName}</span>)<br>
+            Dont Message the quotation marks or it wont work.<br>
+            This is in beta dont expect this shit to work
+         </h2>
+      </center>
+   </body>
+</html>
+      """
+    )
+  elif method == "POST":
+    return sanic.response.html()
+  return sanic.response.json({"error": "Invalid Request Method"})
+
 async def get_items():
   async with aiohttp.ClientSession() as session:
     async with session.request(
       method="GET",
       url="https://fortnite-api.com/v2/cosmetics/br/"
       ) as r:
-      main_ = await r.text()
-  main = json.loads(main_)
-  items = main['data']
-  file = open("items.json", "w")
+      items = await r.json()
+  items = items['data']
+  file = open(
+    "items.json", 
+    "w"
+  )
   json.dump(items, file, indent=2)
   file.close()
   logger.info(green('Cached All bot Items'))
@@ -118,10 +251,13 @@ def open_config():
 def is_admin():
   async def predicate(ctx):
     config = open_config()
-    settings = await get_settings()
-    owners = [i for i in settings['whitelist_id']]
+    try:
+      settings = await get_settings()
+      owners = [i for i in settings['whitelist_id']]
+    except:
+      owners = []
     owners.append(config['owner'])
-    return ctx.author.id in owners
+    return str(ctx.author.id) in owners
   return commands.check(predicate)
 
 def load_cosmetics():
@@ -134,31 +270,31 @@ def load_cosmetics():
       sys.exit()
 
 clear()
-response = input('Enter A Valid Authorization Code: ')
-clear()
-try:
-  url = PirxcyPinger.get_url(platform='replit')
-except:
-  logger.warning(red('Invalid Platform Please Use on Replit!'))
 
-if "redirectUrl" in response:
-  response = json.loads(response)
-  if "?code" not in response["redirectUrl"]:
-    print('You Have Entered An Invalid Authorization Code!')
-    sys.exit()
-  code = response["redirectUrl"].split("?code=")[1]
-else:
-  if "https://accounts.epicgames.com/fnauth" in response:
-    if "?code" not in response:
+
+async def code_to_auths():
+  response = input('Enter A Valid Authorization Code: ')
+  clear()
+  try:
+    url = PirxcyPinger.get_url(platform='replit')
+  except:
+    logger.warning(red('Invalid Platform Please Use on Replit!'))
+
+  if "redirectUrl" in response:
+    response = json.loads(response)
+    if "?code" not in response["redirectUrl"]:
       print('You Have Entered An Invalid Authorization Code!')
       sys.exit()
-    code = response.split("?code=")[1]
+    code = response["redirectUrl"].split("?code=")[1]
   else:
-    code = response
-
-logger.info('Proceeding To Generate Auths!')
-
-async def code_to_auths(code):
+    if "https://accounts.epicgames.com/fnauth" in response:
+      if "?code" not in response:
+        print('You Have Entered An Invalid Authorization Code!')
+        sys.exit()
+      code = response.split("?code=")[1]
+    else:
+      code = response
+  logger.info('Proceeding To Generate Auths!')
   async with aiohttp.ClientSession() as session:
     async with session.request(
       method="POST",
@@ -183,9 +319,28 @@ async def code_to_auths(code):
       data2 = await r.text()
       auths = json.loads(data2)
     auths['created'].pop('ipAddress')
+    with open("config.json") as f:
+      old = json.load(f)
+    
+    with open(
+      "config.json",
+      "w"
+    ) as new:
+      old['auths'].update(auths)
+      json.dump(
+        old,
+        new,
+        indent=2
+      )
+
     logger.info(green('Generated Auths!'))
     return auths
-auths = loop.run_until_complete(code_to_auths(code))
+
+tempc = open_config()
+if tempc.get("auths") and tempc['auths'].get("secret"):
+  auths = tempc['auths']
+else:
+  auths = loop.run_until_complete(code_to_auths())
 
 bot = commands.Bot(
   command_prefix="!",
@@ -197,14 +352,14 @@ bot = commands.Bot(
   )
 )
 
-def botdef():
-  return bot
-
 @bot.event
 async def event_party_invite(invite):
   config = open_config()
-  settings = await get_settings()
-  owners = [i for i in settings['whitelist_id']]
+  try:
+    settings = await get_settings()
+    owners = [i for i in settings['whitelist_id']]
+  except:
+    owners = []
   owners.append(config['owner'])
   if invite.sender.id in owners:
     try:
@@ -222,15 +377,20 @@ async def event_ready() -> None:
   config = open_config()
   if config['owner'] == "":
     logger.warning(red('You Haven\'t Filled Out The Config! (Expect Errors To Occur)'))
-  try:
-    user = await bot.fetch_profile(config['owner'])
-    if user.id in bot.friends:
-      await user.invite()
-    else:
+  user = await bot.fetch_profile(config['owner'])
+  if user.id in bot.friends:
+    friend = bot.get_friend(user.id)
+    try:
+      await friend.join_party()
+    except:
+      await friend.invite()
+  else:
+    try:
       await bot.unblock_user(user.id)
-      await bot.add_friend(user.id)
-  except:
-    pass
+    except:
+      pass
+    await bot.add_friend(user.id)
+    logger.info(green(f"Added {user.display_name} {red('(ADMIN)')}"))
   await get_items()
   await bot.set_presence(config['status']) 
   clear()
@@ -246,8 +406,8 @@ async def event_ready() -> None:
   log = logging.getLogger('werkzeug')
   log.disabled = True
   coro = app.create_server(
-    host='0.0.0.0',
-    port=5595,
+    host=run_ip,
+    port=run_port,
     return_asyncio_server=True,
     debug=False,
     access_log=False
@@ -260,15 +420,18 @@ async def event_ready() -> None:
 @bot.event
 async def event_party_member_join(member):
   config = open_config()
-  settings = await get_settings()
-  owners = [i for i in settings['whitelist_id']]
+  try:
+    settings = await get_settings()
+    owners = [i for i in settings['whitelist_id']]
+  except:
+    owners = []
   owners.append(config['owner'])
   if member.id in owners:
     logger.info(red(f'{member.display_name} (An Admin) Has Joined!'))
     await member.promote()
     await bot.party.send(config['join_message'])
     await bot.party.send("An Admin of This Bot Has Joined!")
-  elif member.display_name in settings['blocked_names']:
+  elif member.display_name in settings['blocked_names'] or member.id in settings['blocked_names']:
     await post_blacklist(id=member.display_name)
     await member.block()
     await member.kick()
@@ -276,40 +439,81 @@ async def event_party_member_join(member):
     logger.info(f'{member.display_name} Has Joined!')
     await bot.party.send(f"{config['join_message']}\nMade By Pirxcy")
     
+@bot.event
+async def event_friend_request(request):
+  config = open_config()
+  try:
+    settings = await get_settings()
+    owners = [i for i in settings['whitelist_id']]
+  except:
+    owners = []
+  owners.append(config['owner'])
+  if request.sender.id in owners:
+    await request.accept()
+    await request.sender.invite()
+
+@bot.event
+async def event_friend_add(friend):
+  await friend.invite()
+
+@bot.event
+async def event_friend_remove(friend):
+  config = open_config()
+  try:
+    settings = await get_settings()
+    owners = [i for i in settings['whitelist_id']]
+  except:
+    owners = []
+  owners.append(config['owner'])
+  if friend.id in owners:
+    await friend.add_friend()
 
 @bot.event
 async def event_friend_message(message):
-  settings = await get_settings()
-  if message.author.display_name in settings['blocked_names']:
+  config = open_config()
+  try:
+    settings = await get_settings()
+    owners = [i for i in settings['whitelist_id']]
+  except:
+    owners = []
+  owners.append(config['owner'])
+  if message.author.display_name in settings['blocked_names'] or message.author.id in settings['blocked_names']:
     await message.author.block()
     await message.author.kick()
     logger.warning(red(f'Blocked/Kicked {message.author.display_name}'))
-    await bot.process_commands(message)
   elif any(word.lower() in message.content.lower() for word in settings['blacklist_keywords']):
     await post_blacklist(id=message.author.id)
+    await message.author.block()
     logger.warning(red(f'Added {message.author.display_name} to the blacklist!'))
-    await bot.process_commands(message)
   else:
-    logger.info(green(f'[{message.author.display_name}] {message.content}'))
-    await bot.process_commands(message)
+    if str(message.author.id) in owners:
+      logger.info(green(f'[{message.author.display_name} {red("ADMIN")}] {message.content}'))
+    else:
+      logger.info(green(f'[{message.author.display_name}] {message.content}'))
 
 @bot.event
 async def event_party_message(message):
-  settings = await get_settings()
-  if message.author.display_name in settings['blocked_names']:
+  config = open_config()
+  try:
+    settings = await get_settings()
+    owners = [i for i in settings['whitelist_id']]
+  except:
+    owners = []
+  owners.append(config['owner'])
+  if message.author.display_name in settings['blocked_names'] or message.author.id in settings['blocked_names']:
     await message.author.block()
     await message.author.kick()
     logger.warning(red(f'Blocked/Kicked {message.author.display_name}'))
-    await bot.process_commands(message)
   elif any(word.lower() in message.content.lower() for word in settings['blacklist_keywords']):
     await post_blacklist(id=message.author.display_name)
     await message.author.block()
     await message.author.kick()
     logger.warning(red(f'Added {message.author.display_name} to the blacklist!'))
-    await bot.process_commands(message)
   else:
-    logger.info(f'[{message.author.display_name}] {message.content}')
-    await bot.process_commands(message)
+    if str(message.author.id) in owners:
+      logger.info(green(f'[{message.author.display_name} {red("ADMIN")}] {message.content}'))
+    else:
+      logger.info(green(f'[{message.author.display_name}] {message.content}'))
 
 @bot.command()
 async def hello(ctx):
@@ -358,7 +562,6 @@ async def skin(ctx, *, content = None):
         def check(m): 
           return m.author.id == ctx.author.id
         msg = await bot.wait_for("party_message", check=check)
-               
         await bot.party.me.set_outfit(asset=result[int(msg.content)]['id'])
         skinname = result[int(msg.content)]['name']
         await ctx.send(f'Equiped {skinname}')
@@ -642,6 +845,23 @@ async def level(ctx, level = None):
     await bot.party.me.set_banner(season_level=level)
     await ctx.send(f'Set level to {level}')
 
+@bot.command()
+@is_admin()
+async def verify(
+  ctx,
+  guess=None
+):
+  if not guess:
+    return await ctx.send("No Code Entered!")
+  elif not code:
+    return await ctx.send(f"Visit {PirxcyPinger.get_url(platform='replit')}/dash first!")
+  elif guess.lower() == code.lower():
+    await ctx.send("Welcome Back, SHlT BOUTTA GO DOWN\n Check your web page")
+
+
+
+
+
 @bot.command()
 @is_admin()
 async def say(ctx, *, message = None):
@@ -690,5 +910,21 @@ async def join(ctx, *, member = None):
   except AttributeError:
       await ctx.send("I can not join that party. Are you sure I have them friended?")
 
+
+
 def run(ip = str, port = int):
+
+  global run_ip
+  global run_port
+  run_ip = ip
+  run_port = port
   bot.run()
+
+
+
+#remove this when compiling
+
+run(
+  ip="127.0.0.1",
+  port=8000
+)
